| Copyright | Will Thompson, Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.OSTree.Flags
Contents
Description
Exported types
data SysrootUpgraderPullFlags Source #
No description available in the introspection data.
Constructors
| SysrootUpgraderPullFlagsNone | No description available in the introspection data. |
| SysrootUpgraderPullFlagsAllowOlder | No description available in the introspection data. |
| SysrootUpgraderPullFlagsSynthetic | No description available in the introspection data. |
| AnotherSysrootUpgraderPullFlags Int | Catch-all for unknown values |
data SysrootUpgraderFlags Source #
Flags controlling operation of an SysrootUpgrader.
Constructors
| SysrootUpgraderFlagsIgnoreUnconfigured | Do not error if the origin has an unconfigured-state key |
| AnotherSysrootUpgraderFlags Int | Catch-all for unknown values |
data SysrootSimpleWriteDeploymentFlags Source #
No description available in the introspection data.
Constructors
| SysrootSimpleWriteDeploymentFlagsNone | No description available in the introspection data. |
| SysrootSimpleWriteDeploymentFlagsRetain | No description available in the introspection data. |
| SysrootSimpleWriteDeploymentFlagsNotDefault | No description available in the introspection data. |
| SysrootSimpleWriteDeploymentFlagsNoClean | No description available in the introspection data. |
| AnotherSysrootSimpleWriteDeploymentFlags Int | Catch-all for unknown values |
data SePolicyRestoreconFlags Source #
No description available in the introspection data.
Constructors
| SePolicyRestoreconFlagsNone | No description available in the introspection data. |
| SePolicyRestoreconFlagsAllowNolabel | No description available in the introspection data. |
| SePolicyRestoreconFlagsKeepExisting | No description available in the introspection data. |
| AnotherSePolicyRestoreconFlags Int | Catch-all for unknown values |
data RepoPullFlags Source #
No description available in the introspection data.
Constructors
| RepoPullFlagsNone | No special options for pull |
| RepoPullFlagsMirror | Write out refs suitable for mirrors |
| RepoPullFlagsCommitOnly | Fetch only the commit metadata |
| RepoPullFlagsUntrusted | Don't trust local remote |
| AnotherRepoPullFlags Int | Catch-all for unknown values |
data RepoListObjectsFlags Source #
No description available in the introspection data.
Constructors
| RepoListObjectsFlagsLoose | List only loose (plain file) objects |
| RepoListObjectsFlagsPacked | List only packed (compacted into blobs) objects |
| RepoListObjectsFlagsAll | List all objects |
| RepoListObjectsFlagsNoParents | Only list objects in this repo, not parents |
| AnotherRepoListObjectsFlags Int | Catch-all for unknown values |
data RepoCommitTraverseFlags Source #
No description available in the introspection data.
Constructors
| RepoCommitTraverseFlagsRepoCommitTraverseFlagNone | No description available in the introspection data. |
| AnotherRepoCommitTraverseFlags Int | Catch-all for unknown values |
data RepoCommitState Source #
No description available in the introspection data.
Constructors
| RepoCommitStateRepoCommitStatePartial | No description available in the introspection data. |
| AnotherRepoCommitState Int | Catch-all for unknown values |
data RepoCommitModifierFlags Source #
No description available in the introspection data.
Constructors
| RepoCommitModifierFlagsNone | No special flags |
| RepoCommitModifierFlagsSkipXattrs | Do not process extended attributes |
| RepoCommitModifierFlagsGenerateSizes | Generate size information. |
| AnotherRepoCommitModifierFlags Int | Catch-all for unknown values |
No description available in the introspection data.
Constructors
| DiffFlagsNone | No description available in the introspection data. |
| DiffFlagsIgnoreXattrs | No description available in the introspection data. |
| AnotherDiffFlags Int | Catch-all for unknown values |