| Copyright | Will Thompson, Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.OSTree.Objects.GpgVerifyResult
Contents
Description
- newtype GpgVerifyResult = GpgVerifyResult (ManagedPtr GpgVerifyResult)
- class GObject o => IsGpgVerifyResult o
- toGpgVerifyResult :: IsGpgVerifyResult o => o -> IO GpgVerifyResult
- noGpgVerifyResult :: Maybe GpgVerifyResult
- data GpgVerifyResultCountAllMethodInfo
- gpgVerifyResultCountAll :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) => a -> m Word32
- data GpgVerifyResultCountValidMethodInfo
- gpgVerifyResultCountValid :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) => a -> m Word32
- data GpgVerifyResultDescribeMethodInfo
- gpgVerifyResultDescribe :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) => a -> Word32 -> String -> Maybe Text -> GpgSignatureFormatFlags -> m ()
- gpgVerifyResultDescribeVariant :: (HasCallStack, MonadIO m) => GVariant -> String -> Maybe Text -> GpgSignatureFormatFlags -> m ()
- data GpgVerifyResultGetMethodInfo
- gpgVerifyResultGet :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) => a -> Word32 -> [GpgSignatureAttr] -> m GVariant
- data GpgVerifyResultGetAllMethodInfo
- gpgVerifyResultGetAll :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) => a -> Word32 -> m GVariant
- data GpgVerifyResultLookupMethodInfo
- gpgVerifyResultLookup :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) => a -> Text -> m (Bool, Word32)
- data GpgVerifyResultRequireValidSignatureMethodInfo
- gpgVerifyResultRequireValidSignature :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) => a -> m ()
Exported types
newtype GpgVerifyResult Source #
Constructors
| GpgVerifyResult (ManagedPtr GpgVerifyResult) |
Instances
| GObject GpgVerifyResult Source # | |
| IsInitable GpgVerifyResult Source # | |
| IsObject GpgVerifyResult Source # | |
| IsGpgVerifyResult GpgVerifyResult Source # | |
| ((~) * info (ResolveGpgVerifyResultMethod t GpgVerifyResult), MethodInfo * info GpgVerifyResult p) => IsLabel t (GpgVerifyResult -> p) Source # | |
| ((~) * info (ResolveGpgVerifyResultMethod t GpgVerifyResult), MethodInfo * info GpgVerifyResult p) => IsLabelProxy t (GpgVerifyResult -> p) Source # | |
| HasAttributeList * GpgVerifyResult Source # | |
| type AttributeList GpgVerifyResult Source # | |
| type SignalList GpgVerifyResult Source # | |
class GObject o => IsGpgVerifyResult o Source #
Instances
toGpgVerifyResult :: IsGpgVerifyResult o => o -> IO GpgVerifyResult Source #
Methods
countAll
data GpgVerifyResultCountAllMethodInfo Source #
Instances
| ((~) * signature (m Word32), MonadIO m, IsGpgVerifyResult a) => MethodInfo * GpgVerifyResultCountAllMethodInfo a signature Source # | |
gpgVerifyResultCountAll Source #
Arguments
| :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) | |
| => a |
|
| -> m Word32 | Returns: signature count |
Counts all the signatures in result.
countValid
data GpgVerifyResultCountValidMethodInfo Source #
Instances
| ((~) * signature (m Word32), MonadIO m, IsGpgVerifyResult a) => MethodInfo * GpgVerifyResultCountValidMethodInfo a signature Source # | |
gpgVerifyResultCountValid Source #
Arguments
| :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) | |
| => a |
|
| -> m Word32 | Returns: valid signature count |
Counts only the valid signatures in result.
describe
data GpgVerifyResultDescribeMethodInfo Source #
Instances
| ((~) * signature (Word32 -> String -> Maybe Text -> GpgSignatureFormatFlags -> m ()), MonadIO m, IsGpgVerifyResult a) => MethodInfo * GpgVerifyResultDescribeMethodInfo a signature Source # | |
gpgVerifyResultDescribe Source #
Arguments
| :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) | |
| => a |
|
| -> Word32 |
|
| -> String |
|
| -> Maybe Text |
|
| -> GpgSignatureFormatFlags |
|
| -> m () |
Appends a brief, human-readable description of the GPG signature at
signatureIndex in result to the outputBuffer. The description
spans multiple lines. A linePrefix string, if given, will precede
each line of the description.
The flags argument is reserved for future variations to the description
format. Currently must be 0.
It is a programmer error to request an invalid signatureIndex. Use
gpgVerifyResultCountAll to find the number of signatures in
result.
describeVariant
gpgVerifyResultDescribeVariant Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => GVariant |
|
| -> String |
|
| -> Maybe Text |
|
| -> GpgSignatureFormatFlags |
|
| -> m () |
Similar to gpgVerifyResultDescribe but takes a GVariant of
all attributes for a GPG signature instead of an GpgVerifyResult
and signature index.
The variant <emphasis>MUST</emphasis> have been created by
gpgVerifyResultGetAll.
get
data GpgVerifyResultGetMethodInfo Source #
Instances
| ((~) * signature (Word32 -> [GpgSignatureAttr] -> m GVariant), MonadIO m, IsGpgVerifyResult a) => MethodInfo * GpgVerifyResultGetMethodInfo a signature Source # | |
Arguments
| :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) | |
| => a |
|
| -> Word32 |
|
| -> [GpgSignatureAttr] |
|
| -> m GVariant | Returns: a new, floating, |
Builds a GVariant tuple of requested attributes for the GPG signature at
signatureIndex in result. See the GpgSignatureAttr description
for the VariantType of each available attribute.
It is a programmer error to request an invalid GpgSignatureAttr or
an invalid signatureIndex. Use gpgVerifyResultCountAll to
find the number of signatures in result.
getAll
data GpgVerifyResultGetAllMethodInfo Source #
Instances
| ((~) * signature (Word32 -> m GVariant), MonadIO m, IsGpgVerifyResult a) => MethodInfo * GpgVerifyResultGetAllMethodInfo a signature Source # | |
gpgVerifyResultGetAll Source #
Arguments
| :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) | |
| => a |
|
| -> Word32 |
|
| -> m GVariant | Returns: a new, floating, |
Builds a GVariant tuple of all available attributes for the GPG signature
at signatureIndex in result.
The child values in the returned GVariant tuple are ordered to match the
GpgSignatureAttr enumeration, which means the enum values can be
used as index values in functions like g_variant_get_child(). See the
GpgSignatureAttr description for the VariantType of each
available attribute.
<note>
<para>
The GpgSignatureAttr enumeration may be extended in the future
with new attributes, which would affect the GVariant tuple returned by
this function. While the position and type of current child values in
the GVariant tuple will not change, to avoid backward-compatibility
issues <emphasis>please do not depend on the tuple's overall size or
type signature</emphasis>.
</para>
</note>
It is a programmer error to request an invalid signatureIndex. Use
gpgVerifyResultCountAll to find the number of signatures in
result.
lookup
data GpgVerifyResultLookupMethodInfo Source #
Instances
| ((~) * signature (Text -> m (Bool, Word32)), MonadIO m, IsGpgVerifyResult a) => MethodInfo * GpgVerifyResultLookupMethodInfo a signature Source # | |
gpgVerifyResultLookup Source #
Arguments
| :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) | |
| => a |
|
| -> Text |
|
| -> m (Bool, Word32) |
Searches result for a signature signed by keyId. If a match is found,
the function returns True and sets outSignatureIndex so that further
signature details can be obtained through gpgVerifyResultGet.
If no match is found, the function returns False and leaves
outSignatureIndex unchanged.
requireValidSignature
data GpgVerifyResultRequireValidSignatureMethodInfo Source #
Instances
| ((~) * signature (m ()), MonadIO m, IsGpgVerifyResult a) => MethodInfo * GpgVerifyResultRequireValidSignatureMethodInfo a signature Source # | |
gpgVerifyResultRequireValidSignature Source #
Arguments
| :: (HasCallStack, MonadIO m, IsGpgVerifyResult a) | |
| => a |
|
| -> m () | (Can throw |
Checks if the result contains at least one signature from the
trusted keyring. You can call this function immediately after
repoVerifySummary or repoVerifyCommitExt -
it will handle the Nothing result and filled error too.